@@ -226,7 +226,7 @@ def populate_azure_snapshot(snapshot, container=None, snapshot_type='azure'):
                                         ('snapshotId', pymongo.ASCENDING)
                                     ]
                                 )
-                            insert_one_document(data, data['collection'], dbname)
+                            insert_one_document(data, data['collection'], dbname, check_keys=False)
                         else:
                             snapshot_dir = make_snapshots_dir(container)
                             if snapshot_dir:
